/*
 * Twain resource definitions
 *
 * Copyright 2006 CodeWeavers, Aric Stewart
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDD_DIALOG1 					0x400
#define IDD_CAMERAUI 					0x401
#define IDD_CONNECTING					0x402

#define IDC_STATIC						999
#define IDC_LIST1                       1000
#define IDC_IMPORT                      1001
#define IDC_IMPORTALL					1002
#define IDC_EXIT                        1003
#define IDC_BITMAP						1004
#define IDC_FETCH						1005
#define IDC_SKIP						1006
